#!/bin/bash
set -eux

function main() {
    upgradeSystem

    apt -qqy install curl git openjdk-17-jre-headless leiningen build-essential libz-dev zlib1g-dev;

    # download kubeconform & graalvm
    curl -Lo /tmp/kubeconform-v0.6.3.tar.gz https://github.com/yannh/kubeconform/releases/download/v0.6.3/kubeconform-linux-amd64.tar.gz
    curl -Lo /tmp/graalvm-community-jdk-17.0.7_linux-x64_bin.tar.gz https://github.com/graalvm/graalvm-ce-builds/releases/download/jdk-17.0.7/graalvm-community-jdk-17.0.7_linux-x64_bin.tar.gz
    
    # checksum
    cd /tmp
    sha256sum --check CHECKSUMS

    # install kubeconform
    tar -xf /tmp/kubeconform-v0.6.3.tar.gz
    cp kubeconform /usr/local/bin

    # install graalvm
    tar -xzf graalvm-community-jdk-17.0.7_linux-x64_bin.tar.gz
    mv graalvm-community-openjdk-17.0.7+7.1 /usr/lib/jvm/
    ln -s /usr/lib/jvm/graalvm-community-openjdk-17.0.7+7.1 /usr/lib/jvm/graalvm
    ln -s /usr/lib/jvm/graalvm/bin/gu /usr/local/bin
    update-alternatives --install /usr/bin/java java /usr/lib/jvm/graalvm/bin/java 2
    gu install native-image
    ln -s /usr/lib/jvm/graalvm/bin/native-image /usr/local/bin

    #install pyb
    apt -qqy install python3 python3-pip;
    pip3 install pybuilder 'ddadevops>=4.2.0' deprecation dda-python-terraform boto3 pyyaml inflection --break-system-packages;   

    cleanupDocker
}

source /tmp/install_functions.sh
main